@@ -27,7 +27,7 @@ def select_Platform(idx):
 
     dtype = np.complex64
     api = cluda.ocl_api()
-    if idx is "selection":
+    if idx == "selection":
         thr = api.Thread.create(interactive=True)
     else:
         thr = api.Thread.create(idx)
@@ -98,10 +98,6 @@ def compile_Kernels(thr):
     program = thr.compile(open(path/"GPU_Kernels/median_filter.cl").read())
     GPU.Median_Filter = program.Median_Filter
 
-    # Check if inside mask
-    program = thr.compile(open(path/"GPU_Kernels/check_mask.cl").read())
-    GPU.check_mask = program.check_mask
-
     # Weighting function
     program = thr.compile(open(path/"GPU_Kernels/Weighting.cl").read())
     GPU.Weighting = program.Weighting
@@ -129,6 +125,8 @@ def initialization(width, height, thr):
     # Obtain PIV mesh
     grid.generate_mesh(width, height)
     grid.pixels = width*height
+    Parameters.Data.height = height
+    Parameters.Data.width = width
 
     # Total number of boxes for global size
     N_boxes_1 = Parameters.no_boxes_1_x*Parameters.no_boxes_1_y
@@ -146,13 +144,13 @@ def initialization(width, height, thr):
     data1 = np.array((width, height,
         Parameters.box_size_1_x, Parameters.box_size_1_y,
         Parameters.no_boxes_1_x, Parameters.no_boxes_1_y,
-        Parameters.window_x_1, Parameters.window_y_1,
-        peak_ratio, Parameters.gaussian_filter)).astype(np.int32)
+        Parameters.window_1_x, Parameters.window_1_y,
+        peak_ratio, Parameters.gaussian_size)).astype(np.int32)
     data2 = np.array((width, height,
         Parameters.box_size_2_x, Parameters.box_size_2_y,
         Parameters.no_boxes_2_x, Parameters.no_boxes_2_y,
-        Parameters.window_x_2, Parameters.window_y_2,
-        peak_ratio, Parameters.gaussian_filter)).astype(np.int32)
+        Parameters.window_2_x, Parameters.window_2_y,
+        peak_ratio, Parameters.gaussian_size)).astype(np.int32)
 
     # Send mesh to gpu (only done once)
     GPU.box_origin_x_1 = thr.to_device(grid.box_origin_x_1)
@@ -165,11 +163,15 @@ def initialization(width, height, thr):
     GPU.x2 = thr.to_device(grid.x_2)
     GPU.y2 = thr.to_device(grid.y_2)
 
+    if Parameters.mask:
+        GPU.mask_1 = thr.to_device(grid.mask_1)
+        GPU.mask_2 = thr.to_device(grid.mask_2)
+
     if Parameters.direct_calc:
         GPU.box_origin_x_d = thr.to_device(grid.box_origin_x_d)
         GPU.box_origin_y_d = thr.to_device(grid.box_origin_y_d)
-        box_size_x_d = round(Parameters.window_x_1/2)*2+1;
-        box_size_y_d = round(Parameters.window_y_1/2)*2+1;
+        box_size_x_d = round(Parameters.window_1_x/2)*2+1;
+        box_size_y_d = round(Parameters.window_1_y/2)*2+1;
         directCorr = np.zeros((N_boxes_1, box_size_y_d,
             box_size_x_d), dtype = np.float32)
 
@@ -277,9 +279,9 @@ def initialization(width, height, thr):
         GPU.u_index_1])
 
     #Create temp images for gaussian filter if needed
-    if (Parameters.gaussian_filter):
+    if (Parameters.gaussian_size):
 
-        kernel = DPIV.gaussian_kernel(Parameters.gaussian_filter)
+        kernel = DPIV.gaussian_kernel(Parameters.gaussian_size)
         GPU.kernel = thr.to_device(np.float32(kernel))
 
         # Images filtered to be used only on first iteration
@@ -480,7 +482,7 @@ def processing(img1_name, img2_name, thr):
                 global_size = grid.pixels)
 
     # Apply gaussian blur only on first iteration if required
-    if Parameters.gaussian_filter:
+    if Parameters.gaussian_size:
         GPU.gaussian_filter(GPU.img1_g, GPU.img1, GPU.kernel, GPU.data1,
                 local_size = None, global_size = grid.pixels)
         GPU.gaussian_filter(GPU.img2_g, GPU.img2, GPU.kernel, GPU.data1,
@@ -522,9 +524,10 @@ def processing(img1_name, img2_name, thr):
 
             # Velocity=0 inside mask to prevent bleeding from median filter
             if Parameters.mask:
-                GPU.check_mask(GPU.u1_f, GPU.v1_f, GPU.x1, GPU.y1,
-                        GPU.mask, GPU.data1, local_size = None,
-                        global_size = N_boxes_1)
+                GPU.masking(GPU.u1_f, GPU.u1_f, GPU.mask_1,
+                        local_size = None, global_size = N_boxes_1)
+                GPU.masking(GPU.v1_f, GPU.v1_f, GPU.mask_1,
+                        local_size = None, global_size = N_boxes_1)
 
             # Jacobian matrix
             GPU.jacobian(GPU.temp_dx_1, GPU.temp_dy_1, GPU.u1_f, GPU.x1, GPU.y1,
@@ -666,9 +669,10 @@ def processing(img1_name, img2_name, thr):
 
         if Parameters.mask:
             # Check if inside mask to prevent bleeding from median filter
-            GPU.check_mask(GPU.u2_f, GPU.v2_f, GPU.x2, GPU.y2,
-                    GPU.mask, GPU.data2, local_size = None,
-                    global_size = N_boxes_2)
+            GPU.masking(GPU.u2_f, GPU.u2_f, GPU.mask_2,
+                    local_size = None, global_size = N_boxes_2)
+            GPU.masking(GPU.v2_f, GPU.v2_f, GPU.mask_2,
+                    local_size = None, global_size = N_boxes_2)
 
     # Load Images of next iteration during runtime
     Img1, Img2 = DPIV.load_images(img1_name, img2_name)
