@@ -48,10 +48,10 @@ class Parameters:
     mask = 0
     peak_ratio = 1
     weighting = 0
-    gaussian_filter = 0
+    gaussian_size = 0
     median_limit = 0.5
-    factor = 1
-    dt = 1
+    calibration = 1
+    delta_t = 1
 
     #Extra data needed in some cases
     class Data:
@@ -66,46 +66,60 @@ class Parameters:
         with open(fileName) as f:
             data = yaml.load(f, Loader=yaml.FullLoader)
 
-            #Default first step parameters
-            self.box_size_1_x = data['box_size_1_x']
-            self.box_size_1_y = data['box_size_1_y']
-            self.no_boxes_1_x = data['no_boxes_1_x']
-            self.no_boxes_1_y = data['no_boxes_1_y']
-            self.window_x_1 =   data['window_x_1']
-            self.window_y_1 =   data['window_y_1']
+            try:
+                #Default first step parameters
+                self.box_size_1_x = data['box_size_1_x']
+                self.box_size_1_y = data['box_size_1_y']
+                self.no_boxes_1_x = data['no_boxes_1_x']
+                self.no_boxes_1_y = data['no_boxes_1_y']
+                self.window_1_x =   data['window_1_x']
+                self.window_1_y =   data['window_1_y']
 
-            #Number of pass of first step
-            self.no_iter_1 = data['no_iter_1']
-            self.no_iter_2 = data['no_iter_2']
+                #Number of pass of first step
+                self.no_iter_1 = data['no_iter_1']
+                self.no_iter_2 = data['no_iter_2']
 
-            #Direct calculation or FFT
-            self.direct_calc = data['direct_calc']
+                #Direct calculation or FFT
+                self.direct_calc = data['direct_calc']
 
-            #Default first step parameters
-            self.box_size_2_x = data['box_size_2_x']
-            self.box_size_2_y = data['box_size_2_y']
-            self.no_boxes_2_x = data['no_boxes_2_x']
-            self.no_boxes_2_y = data['no_boxes_2_y']
-            self.window_x_2 =   data['window_x_2']
-            self.window_y_2 =   data['window_y_2']
+                #Default first step parameters
+                self.box_size_2_x = data['box_size_2_x']
+                self.box_size_2_y = data['box_size_2_y']
+                self.no_boxes_2_x = data['no_boxes_2_x']
+                self.no_boxes_2_y = data['no_boxes_2_y']
+                self.window_2_x =   data['window_2_x']
+                self.window_2_y =   data['window_2_y']
 
-            #default general parameters
-            self.mask = data['mask']
-            self.peak_ratio = data['peak_ratio']
-            self.weighting = data['weighting']
-            self.gaussian_filter = data['gaussian_filter']
-            self.median_limit = data['median_limit']
-            self.factor = data['factor']
-            self.dt = data['dt']
+                #default general parameters
+                self.mask = data['mask']
+                self.peak_ratio = data['peak_ratio']
+                self.weighting = data['weighting']
+                self.gaussian_size = data['gaussian_size']
+                self.median_limit = data['median_limit']
+                self.calibration = data['calibration']
+                self.delta_t = data['delta_t']
 
-            #Extra data
-            if self.mask:
-                if data['path_mask'].endswith('.np'):
-                    self.Data.mask = bool(np.load(data['path_mask']))
-                else:
-                    self.Data.mask = np.asarray(cv2.cvtColor(cv2.imread(
-                        data['path_mask']), cv2.COLOR_BGR2GRAY)).astype(bool)
+                #Extra data
+                if self.mask:
+                    if data['path_mask'].endswith('.np'):
+                        self.Data.mask = bool(np.load(data['path_mask']))
+                    else:
+                        self.Data.mask = np.asarray(cv2.cvtColor(cv2.imread(
+                            data['path_mask']), cv2.COLOR_BGR2GRAY)).astype(bool)
 
+            except:
+                print('Error: Wrong parameters definition. Some Parameters'
+                      ' have been renamed in order to make them'
+                      ' more consistent with the matlab DPIVSoft version.'
+                      ' Please rename the following parameters as indicated:')
+                print(" - Window_axis_number --> window_number_axis")
+                print(" - gaussian_filter --> gaussian_size")
+                print(" - factor --> calibration")
+                print(" - dt --> delta_t")
+                print("You can also check the new parameters definition in "
+                        "Classes.py file or copy them from the examples. "
+                        "Sorry for the inconvenience.")
+                exit()
     def introParameters():
         """
         Introduce a parameter manually, not implemented yet (probably
@@ -191,6 +205,20 @@ class grid:
         cls.box_origin_x_2 = box_origin_x_2.astype(np.int32)
         cls.box_origin_y_2 = box_origin_y_2.astype(np.int32)
 
+
+        #Create mask mesh if needed
+        cls.mask_1 = np.full(x_1.shape, False)
+        cls.mask_2 = np.full(x_2.shape, False)
+        if Parameters.mask:
+            for j in range(0,len(x_1[:,0])):
+                for i in range(0,len(x_1[0,:])):
+                    if Parameters.Data.mask[int(y_1[j,i]),int(x_1[j,i])]:
+                        cls.mask_1[j,i] = True
+            for j in range(0,len(x_2[:,0])):
+                for i in range(0,len(x_2[0,:])):
+                    if Parameters.Data.mask[int(y_2[j,i]),int(x_2[j,i])]:
+                        cls.mask_2[j,i] = True
+
     def read_mesh(self,height,width):
         """
         Read the positions of a custon mesh from a file (not implemented yet)
