@@ -2,17 +2,22 @@
 import numpy as np
 from scipy import ndimage
 from scipy import interpolate
+from scipy.io import savemat
 import copy
 import cv2
 import time
 from dpivsoft.Classes  import Parameters
 from dpivsoft.Classes  import GPU
+from dpivsoft.Classes  import grid
 
 import matplotlib.pyplot as plt
 
 #PROCESS PIV
 def processing(Img1, Img2):
 
+    #Generate x-y mesh for the PIV 
+    grid.generate_mesh(Img1.shape[1], Img1.shape[0])
+
     # Apply mask to images
     if Parameters.mask:
         [Img1, Img2] = masking(Img1, Img2)
@@ -32,6 +37,7 @@ def processing(Img1, Img2):
     # Second cross-correlation
     [x2, y2, u2, v2] = corrFFT2(Img1, Img2, x1, y1, u1, v1)
 
+
     return x2, y2, u2, v2
 
 
@@ -43,16 +49,18 @@ def corrFFT1(Img1, Img2):
     box_size_y = Parameters.box_size_1_y
     no_boxes_1_x = Parameters.no_boxes_1_x
     no_boxes_1_y = Parameters.no_boxes_1_y
-    window_x = Parameters.window_x_1
-    window_y = Parameters.window_y_1
+    window_x = Parameters.window_1_x
+    window_y = Parameters.window_1_y
 
     [Height,Width] = Img1.shape
+    Parameters.Data.height = Height
+    Parameters.Data.width = Width
 
     # Initialize all matrix
-    box_origin_x_1 = np.zeros([no_boxes_1_y, no_boxes_1_x])
-    box_origin_y_1 = np.zeros([no_boxes_1_y, no_boxes_1_x])
-    x_1 = np.zeros([no_boxes_1_y, no_boxes_1_x])
-    y_1 = np.zeros([no_boxes_1_y, no_boxes_1_x])
+    box_origin_x_1 = grid.box_origin_x_1
+    box_origin_y_1 = grid.box_origin_y_1
+    x_1 = grid.x_1
+    y_1 = grid.y_1
     u_1 = np.zeros([no_boxes_1_y, no_boxes_1_x])
     v_1 = np.zeros([no_boxes_1_y, no_boxes_1_x])
 
@@ -67,20 +75,12 @@ def corrFFT1(Img1, Img2):
                 box_size_x, box_size_y)
 
     # Apply Gaussian filter to images only for first iteration
-    if Parameters.gaussian_filter:
-        [Img1, Img2] = gaussian_filter(Img1, Img2, Parameters.gaussian_filter)
+    if Parameters.gaussian_size:
+        [Img1, Img2] = gaussian_filter(Img1, Img2, Parameters.gaussian_size)
 
     for i in range(0, no_boxes_1_x):
         for j in range(0, no_boxes_1_y):
 
-            box_origin_x_1[j,i] = (1 + np.round((i)*(Width-box_size_x-2)
-                /(no_boxes_1_x-1)))
-            box_origin_y_1[j,i] = (1 + np.round((j)*(Height-box_size_y-2)
-                /(no_boxes_1_y-1)))
-
-            x_1[j,i] = (box_origin_x_1[j,i]-1+box_size_x/2)
-            y_1[j,i] = (box_origin_y_1[j,i]-1+box_size_y/2)
-
             # Define sub images to work
             box_o_y = int(box_origin_y_1[j,i])
             box_o_x = int(box_origin_x_1[j,i])
@@ -130,11 +130,11 @@ def corrFFT1bis(Img1, Img2, x_1, y_1, u_1, v_1):
     box_size_y = Parameters.box_size_1_y
     no_boxes_1_x = Parameters.no_boxes_1_x
     no_boxes_1_y = Parameters.no_boxes_1_y
-    window_x = Parameters.window_x_1
-    window_y = Parameters.window_y_1
+    window_x = Parameters.window_1_x
+    window_y = Parameters.window_1_y
     median_limit = Parameters.median_limit
     weighting = Parameters.weighting
-    gaussian = Parameters.gaussian_filter
+    gaussian = Parameters.gaussian_size
 
     [Height,Width] = Img1.shape
 
@@ -160,8 +160,7 @@ def corrFFT1bis(Img1, Img2, x_1, y_1, u_1, v_1):
         # If mask check points to prevent bleeding
         if Parameters.mask:
             # Check points inside the mask
-            u_1, v_1 = check_mask(x_1, y_1, u_1, v_1)
-
+            u_1, v_1 = check_mask(u_1, v_1, grid.mask_1)
 
         # Calculates the jacobian matrix onto de grid
         du_dx, du_dy, dv_dx, dv_dy = jacobian_matrix(u_1, v_1, x_1, y_1,
@@ -218,8 +217,8 @@ def corrFFT2(Img1, Img2, x_1, y_1, u_1, v_1):
     box_size_2_y = Parameters.box_size_2_y
     no_boxes_2_x = Parameters.no_boxes_2_x
     no_boxes_2_y = Parameters.no_boxes_2_y
-    window_x = Parameters.window_x_2
-    window_y = Parameters.window_y_2
+    window_x = Parameters.window_2_x
+    window_y = Parameters.window_2_y
     median_limit = Parameters.median_limit
 
 
@@ -244,10 +243,8 @@ def corrFFT2(Img1, Img2, x_1, y_1, u_1, v_1):
     y_margin = 3/2*np.amax([box_size_1_y, box_size_2_y])
 
     # Second grid is placed completely inside first one
-    x_2 = (2 + np.round(np.arange(0, no_boxes_2_x) *
-        (Width - x_margin - 6)/(no_boxes_2_x - 1) + x_margin/2))
-    y_2 = (2 + np.round(np.arange(0, no_boxes_2_y) *
-        (Height - y_margin - 6)/(no_boxes_2_y - 1)+y_margin/2))
+    x_2 = grid.x_2[0, :]
+    y_2 = grid.y_2[:, 0]
 
     # Calculate Jacobian Matrix
     Interpolation_Start = time.time()
@@ -317,7 +314,7 @@ def corrFFT2(Img1, Img2, x_1, y_1, u_1, v_1):
     # If mask check points to prevent bleeding
     if Parameters.mask:
         # Check points inside the mask
-        u_2, v_2 = check_mask(x_2, y_2, u_2, v_2)
+        u_2, v_2 = check_mask(u_2, v_2, grid.mask_2)
 
 
     return x_2, y_2, u_2, v_2
@@ -350,8 +347,8 @@ def corrDirect1(Img1, Img2):
                 box_size_x, box_size_y)
 
     # Apply Gaussian filter to images only for first iteration
-    if Parameters.gaussian_filter:
-        [Img1, Img2] = gaussian_filter(Img1, Img2, Parameters.gaussian_filter)
+    if Parameters.gaussian_size:
+        [Img1, Img2] = gaussian_filter(Img1, Img2, Parameters.gaussian_size)
 
     for j in range(0, no_boxes_1_y):
         for i in range(0, no_boxes_1_x):
@@ -906,7 +903,6 @@ def deform_image(Img1, Img2, Width, Height, box_origin_x, box_origin_y,
     i_index=box_origin_x[j,i]+i_matrix
     j_index=box_origin_y[j,i]+j_matrix
 
-
     u_index = (u[j,i] * np.ones([box_size_y, box_size_x]) + du_dx[j,i] *
             i_matrix + du_dy[j,i] * j_matrix - (box_size_x)/2 *
             (du_dx[j,i]+du_dy[j,i])*np.ones([box_size_y,box_size_x]))
@@ -915,7 +911,6 @@ def deform_image(Img1, Img2, Width, Height, box_origin_x, box_origin_y,
             i_matrix+dv_dy[j,i]*j_matrix - (box_size_y)/2 *
             (dv_dx[j,i]+dv_dy[j,i])*np.ones([box_size_y,box_size_x]))
 
-
     # Position of translated pixels of images 1 and 2 according to
     # velocity field
     [i_frac_1, j_frac_1, i_frac_2, j_frac_2, j_index_1,
@@ -972,24 +967,19 @@ def change_mask(SubImg1, SubImg2):
     unmasked_pixels = np.count_nonzero(SubImg1)
     SubImg2[SubImg2 == 0] = sum(sum(SubImg2))/max(unmasked_pixels,1)
 
-
     return SubImg1, SubImg2
 
-def check_mask(x, y, u ,v):
+def check_mask(u ,v, mask):
     """
     If the center of the correlation box is inside the mask set
     velocity to 0. Useful for no-slip condition and prevent bleeding
     crossing the mask edge due to median filter
     """
+    u = u*mask
+    v = v*mask
 
-    for j in range(0,len(x[:,0])):
-        for i in range(0,len(x[0,:])):
-            if not Parameters.Data.mask[int(y[j,i]),int(x[j,i])]:
-                u[j,i] = 0
-                v[j,i] = 0
     return u, v
 
-
 def load_images(name_img_1, name_img_2):
     """
     Load images for PIV processing. Add a little value to prevent
@@ -1004,7 +994,7 @@ def load_images(name_img_1, name_img_2):
 
     return Img1, Img2
 
-def save(x, y, u, v, filename, option='dpivsoft',):
+def save(x, y, u, v, filename, option='dpivsoft', Matlab=False, param=False):
     """
     save flow field to a file. Option indicates the saving
     format.
@@ -1016,23 +1006,73 @@ def save(x, y, u, v, filename, option='dpivsoft',):
     with openpiv
     """
 
+    # Scale results
+    x = x * Parameters.calibration
+    y = y * Parameters.calibration
+    u = u * Parameters.calibration/Parameters.delta_t
+    v = v * Parameters.calibration/Parameters.delta_t
+
+    if Matlab:
+        mdic = {"x":x*1.0,  "y":y*1.0,  "u":u*1.0, "v":v*1.0,
+               "calibration": float(Parameters.calibration),
+               "delta_t": float(Parameters.delta_t),
+               "median_limit": float(Parameters.median_limit),
+               "no_calculation_1": float(Parameters.no_iter_1),
+               "no_calculation_2": float(Parameters.no_iter_2),
+               "box_size_1_x": float(Parameters.box_size_1_x),
+               "box_size_1_y": float(Parameters.box_size_1_y),
+               "box_size_2_x": float(Parameters.box_size_2_x),
+               "box_size_2_y": float(Parameters.box_size_2_y),
+               "no_boxes_1_x": float(Parameters.no_boxes_1_x),
+               "no_boxes_1_y": float(Parameters.no_boxes_1_y),
+               "no_boxes_2_x": float(Parameters.no_boxes_2_x),
+               "no_boxes_2_y": float(Parameters.no_boxes_2_y),
+               "no_calculation": float(Parameters.no_iter_1),
+               "direct_calculation": float(Parameters.direct_calc),
+               "gaussian_size": float(Parameters.gaussian_size),
+               "window_1_x": float(Parameters.window_1_x),
+               "window_1_y": float(Parameters.window_1_y),
+               "window_2_x": float(Parameters.window_2_x),
+               "window_2_y": float(Parameters.window_2_y),
+               "weighting": float(Parameters.weighting),
+               "peak_ratio": float(Parameters.peak_ratio),
+               "image_width": float(Parameters.Data.width),
+               "image_height": float(Parameters.Data.height),
+               "mask": float(Parameters.mask)}
+        savemat(filename+'.mat', mdic)
+
     if option == 'dpivsoft':
-        np.savez(filename, x=x,  y=y,  u=u,  v=v,
-                calibration=Parameters.factor,
-                delta_t=Parameters.dt,
-                median_limit=Parameters.median_limit,
-                box_size_1_x=Parameters.box_size_1_x,
-                box_size_1_y=Parameters.box_size_1_y,
-                box_size_2_x=Parameters.box_size_2_x,
-                box_size_2_y=Parameters.box_size_2_y,
-                weighting=Parameters.weighting,
-                peak_ratio=Parameters.peak_ratio)
+        if param:
+            np.savez(filename, x=x,  y=y,  u=u,  v=v,
+                    calibration = Parameters.calibration,
+                    delta_t = Parameters.delta_t,
+                    median_limit = Parameters.median_limit,
+                    gaussian_size = Parameters.gaussian_size,
+                    no_calculation_1 = Parameters.no_iter_1,
+                    no_calculation_2 = Parameters.no_iter_2,
+                    box_size_1_x = Parameters.box_size_1_x,
+                    box_size_1_y = Parameters.box_size_1_y,
+                    box_size_2_x = Parameters.box_size_2_x,
+                    box_size_2_y = Parameters.box_size_2_y,
+                    window_1_x = Parameters.window_1_x,
+                    window_1_y = Parameters.window_1_y,
+                    window_2_x = Parameters.window_2_x,
+                    window_2_y = Parameters.window_2_y,
+                    weighting = Parameters.weighting,
+                    peak_ratio = Parameters.peak_ratio,
+                    mask = Parameters.mask,
+                    direct_calc = Parameters.direct_calc
+                    )
+        else:
+            np.savez(filename, x=x,  y=y,  u=u,  v=v,
+                    calibration = Parameters.calibration)
 
     elif option == 'openpiv':
         fmt="%8.4f"
         delimiter="\t"
+
         # Build output array
-        out = np.vstack([m.flatten() for m in [x, y, u, v]])
+        out = np.vstack([m.flatten() for m in [x, y, u, v, grid.mask_2]])
 
         np.savetxt(
             filename,
@@ -1051,3 +1091,4 @@ def save(x, y, u, v, filename, option='dpivsoft',):
             )
     else:
         sys.exit("Saving option not found")
+
